Struct Label
pub struct Label { /* private fields */ }Implementations
impl Label
impl Label
pub fn try_downcast( element: &(dyn ElementExt + 'static), ) -> Option<LabelElement>
pub fn max_lines(self, max_lines: impl Into<Option<usize>>) -> Label
pub fn max_lines(self, max_lines: impl Into<Option<usize>>) -> Label
Limit the label to at most this many lines, truncating the rest. Pass None for no limit.
pub fn line_height(self, line_height: impl Into<Option<f32>>) -> Label
pub fn line_height(self, line_height: impl Into<Option<f32>>) -> Label
Override the height of each line as a multiple of the font size. Pass None for the default.